@@ -23,19 +23,13 @@ from packaging import tags, version as _packaging_version
 from wheel.wheelfile import WheelFile
 
 from .. import Command, __version__, _shutil
+from .._normalization import safer_name
 from ..warnings import SetuptoolsDeprecationWarning
 from .egg_info import egg_info as egg_info_cls
 
 from distutils import log
 
 
-def safe_name(name: str) -> str:
-    """Convert an arbitrary string to a standard distribution name
-    Any runs of non-alphanumeric/. characters are replaced with a single '-'.
-    """
-    return re.sub("[^A-Za-z0-9.]+", "-", name)
-
-
 def safe_version(version: str) -> str:
     """
     Convert an arbitrary string to a standard version string
@@ -133,10 +127,6 @@ def get_abi_tag() -> str | None:
     return abi
 
 
-def safer_name(name: str) -> str:
-    return safe_name(name).replace("-", "_")
-
-
 def safer_version(version: str) -> str:
     return safe_version(version).replace("-", "_")
 
@@ -184,9 +174,7 @@ class bdist_wheel(Command):
         (
             "compression=",
             None,
-            "zipfile compression (one of: {}) [default: 'deflated']".format(
-                ", ".join(supported_compressions)
-            ),
+            f"zipfile compression (one of: {', '.join(supported_compressions)}) [default: 'deflated']",
         ),
         (
             "python-tag=",
@@ -296,7 +284,7 @@ class bdist_wheel(Command):
             raise ValueError(
                 f"`py_limited_api={self.py_limited_api!r}` not supported. "
                 "`Py_LIMITED_API` is currently incompatible with "
-                f"`Py_GIL_DISABLED` ({sys.abiflags=!r}). "
+                "`Py_GIL_DISABLED`."
                 "See https://github.com/python/cpython/issues/111506."
             )
 
@@ -500,7 +488,7 @@ class bdist_wheel(Command):
             # Setuptools has resolved any patterns to actual file names
             return self.distribution.metadata.license_files or ()
 
-        files: set[str] = set()
+        files = set[str]()
         metadata = self.distribution.get_option_dict("metadata")
         if setuptools_major_version >= 42:
             # Setuptools recognizes the license_files option but does not do globbing
